#
# spec file for package python-sqlobject
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.



Name:           python-sqlobject
Summary:        Object-Relational Manager for Python
Version:        0.10.5
Release:        1.1
%define modname SQLObject
Url:            http://sqlobject.org/
License:        LGPL
Group:          Development/Libraries/Python
Source:         %{modname}-%{version}.tar.bz2
Patch1:         python-sqlobject-0.10.5-deprecated_warning.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       python-formencode
%{py_requires}
BuildRequires:  python-devel python-formencode python-setuptools

%description
SQLObject is an object-relational mapper. It allows you to translate RDBMS
table rows into Python objects, and manipulate those objects to transparently
manipulate the database.

Authors:
--------
    Ian Bicking <ianb@colorstudy.com>

%prep
%setup -q -n %{modname}-%{version}
%if 0%{suse_version} > 1100
%patch1 -p0
%endif

%build
export CFLAGS="$RPM_OPT_FLAGS"
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=$RPM_BUILD_ROOT --record-rpm=INSTALLED_FILES
sed -i "s|^/usr/bin/sqlobject-admin|\%attr(0755,root,root) /usr/bin/sqlobject-admin|" INSTALLED_FILES

%clean
rm -rf %{buildroot}

%files -f INSTALLED_FILES
%defattr(0644,root,root,0755)
%doc docs README.txt

%changelog
* Fri Jun  5 2009 lars@linux-schulserver.de
- only use the patch on suse versions > 1100
* Fri May 15 2009 lars@linux-schulserver.de
- Update to 0.10.5:
  + A number of changes ported from SQLObject 0.9.10
  + sqlmeta.getColumns() becomes classmethod
- fix permissions for sqlobject-admin and documentation
- do not print deprecation warnings on newer python versions
  (python-sqlobject-0.10.5-deprecated_warning.patch)
* Mon Dec 15 2008 jfunk@funktronics.ca
- Update to 0.10.4
* Wed Nov 12 2008 @gmail.com
- Changed --record to --record-rpm as per bnc#441794
* Mon Jan 21 2008 jfunk@funktronics.ca
- Update to 0.8.7:
  - A number of changes ported from SQLObject 0.7.10
* Wed Oct 31 2007 jfunk@funktronics.ca
- Update to 0.8.6
* Thu Jul  5 2007 jfunk@funktronics.ca
- Update to 0.8.4
  - A number of bugfixes forward-ported from 0.7.x
* Mon Apr 23 2007 jfunk@funktronics.ca
- Update to 0.8.2
  - Fixed ConnectionHub.doInTransaction() - if the original connection was
  processConnection - reset processConnection, not threadConnection
* Tue Mar 20 2007 jfunk@funktronics.ca
- Update to 0.8.1:
  - Bug Fixes
  - ID columns are reverted back from INT UNSIGNED to INT for MySQL to be in
  accord with FOREIGN KEYs
  - Fixed return value from Firebird/MaxdbConnection.createTable()
  - Fixed and simplified DatabaseIndex.get()
  - Fixed ConnectionHub.doInTransaction() - close low-level connection on
  commit() to prevent connections leaking
- Changes in 0.8.0:
  - Features & Interface
  - It is now possible to create tables that reference each other.
  Constraints (in the DBMSes that support constraints) are added after the
  tables have been created
  - Added createSQL as an option for sqlmeta. Here you can add related SQL
  you want executed by sqlobject-admin create after table creation
  createSQL expects a string, list, or dictionary. If using a dictionary
  the key should be a dbName value (ex. 'postgres') and the value should be
  a string or list. Examples in sqlobject/tests/test_sqlobject_admin.py or
  at <http://sqlobject.org/sqlobject-admin.html#the-create-command>
  - Added method sqlhub.doInTransaction(callable, *args, **kwargs), to be used like:
  sqlhub.doInTransaction(process_request, os.environ)
  This will run process_request(os.environ). The return value will be preserved
  - Added method .getOne([default]) to SelectResults (these are the objects
  returned by .select() and .selectBy()). This returns a single object,
  when the query is expected to return only one object. The single argument
  is the value to return when zero results are found (more than one result
  is always an error). If no default is given, it is an error if no such
  object exists
  - Added a WSGI middleware (in sqlobject.wsgi_middleware) for configuring
  the database for the request. Also handles transactions. Available as
  egg:SQLObject in Paste Deploy configuration files
  - New joins! ManyToMany and OneToMany; not fully documented yet, but still
  more sensible and smarter
  - SELECT FOR UPDATE
  - New module dberrors.py - a hierarchy of exceptions. Translation of DB API
  module's exceptions to the new hierarchy is performed for SQLite and
  MySQL
  - SQLiteConnection got a new keyword "factory" - a name or a reference to a
  factory function that returns a connection class; useful for implementing
  functions or aggregates. See test_select.py and test_sqlite_factory.py
  for examples
  - SQLObject now disallows columns with names that collide with existing
  variables and methods, such as "_init", "expire", "set" and so on
  - Small Features
  - Configurable client character set (encoding) for MySQL
  - Added a close option to .commit(), so you can close the transaction as
  you commit it
  - DecimalValidator
  - Added .expireAll() methods to sqlmeta and connection objects, to expire
  all instances in those cases
  - String IDs
  - FOREIGN KEY for MySQL
  - Support for sqlite3 (a builtin module in Python 2.5)
  - SelectResults cannot be queried for truth value; in any case it was
  meaningless - the result was always True; now __nonzero__() raises
  NotImplementedError in case one tries bool(MyTable.select()) or "if
  MyTable.select():..."
  - With empty parameters AND() and OR() returns None
  - Allows to use set/frozenset sets/Set/ImmutableSet sets as sequences
  passed to the IN operator
  - ID columns are now INT UNSIGNED for MySQL
  - Bug Fixes
  - Fixed problem with sqlite and threads; connections are no longer shared
  between threads for sqlite (except for :memory:)
  - The reference loop between SQLObject and SQLObjectState eliminated using
  weak references
  - Another round of bugfixes for MySQL errors 2006 and 2013 (SERVER_GONE,
  SERVER_LOST)
  - Fixed a bug in MSSQLConnection caused by column names being unicode
  - Fixed a bug in FirebirdConnection caused by column names having trailing
  spaces
  - Order by several columns with inheritance
  - Fixed aggregators and accumulators with inheritance
* Sat Jan 20 2007 - judas_iscariote@shorewall.net
- update to version 0.7.2
* Sun Oct 29 2006 - poeml@suse.de
- remove obsolete SQLObject-0.7rc1-psycopg2.patch
* Thu Oct 26 2006 jfunk@funktronics.ca
- Update to 0.7.1
* Fri Jun 23 2006 jfunk@funktronics.ca
- No longer need pth kludge
* Thu Jun 22 2006 jfunk@funktronics.ca
- Update
* Wed Oct 19 2005 jfunk@funktronics.ca
- Use psycopg2 for postgresql
* Thu Oct 13 2005 jfunk@funktronics.ca
- Update
- Build for SL10
* Wed Sep 21 2005 jfunk@funktronics.ca
- Update
* Tue Sep 20 2005 jfunk@funktronics.ca
- Initial release
